tdub.rex
--------

A module for parsing TRExFitter results and producing additional
plots/tables.

.. currentmodule:: tdub.rex

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   NuisPar
   TH1
   TGraphAsymmErrors

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   available_regions
   chisq
   chisq_text
   data_histogram
   delta_poi
   meta_axis_label
   meta_text
   nuispar_impact
   nuispar_impacts
   nuispar_impact_plot_df
   nuispar_impact_plot_top15
   plot_all_regions
   plot_region_stage_ff
   prefit_total_and_uncertainty
   prefit_histogram
   prefit_histograms
   prettify_nuispar_label
   postfit_available
   postfit_total_and_uncertainty
   postfit_histogram
   postfit_histograms
   stack_canvas

Reference
^^^^^^^^^


.. autoclass:: NuisPar
.. autoclass:: TH1
   :members:
.. autoclass:: TGraphAsymmErrors
   :members:
.. autofunction:: available_regions
.. autofunction:: chisq
.. autofunction:: chisq_text
.. autofunction:: data_histogram
.. autofunction:: delta_poi
.. autofunction:: plot_all_regions
.. autofunction:: plot_region_stage_ff
.. autofunction:: meta_axis_label
.. autofunction:: meta_text
.. autofunction:: nuispar_impact
.. autofunction:: nuispar_impacts
.. autofunction:: nuispar_impact_plot_df
.. autofunction:: nuispar_impact_plot_top15
.. autofunction:: prefit_total_and_uncertainty
.. autofunction:: prefit_histogram
.. autofunction:: prefit_histograms
.. autofunction:: prettify_nuispar_label
.. autofunction:: postfit_available
.. autofunction:: postfit_total_and_uncertainty
.. autofunction:: postfit_histogram
.. autofunction:: postfit_histograms
.. autofunction:: stack_canvas
